==> rdt-server-linux.ppc-4.1.0.tar: rdt-server/server.pl <==
#!/usr/bin/perl
#*******************************************************************************
# Copyright (c) 2005, 2008 IBM Corporation, Wind River Systems, Inc. and others.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# Contributors:
# IBM Corporation - initial API and implementation
# Martin Oberhuber (Wind River) - Fix bug 149129 - Perl String compare with eq
#*******************************************************************************

$port = $ARGV[0];
$timeout = $ARGV[1];
$clientUserID = $ARGV[2];

$dir= $ENV{PWD};
#print("path $dir");

#$plugins_dir=substr($dir,0,rindex($dir,"/"));
$plugins_dir=$dir;

$ENV{A_PLUGIN_PATH}="$plugins_dir/";

$oldClasspath = $ENV{CLASSPATH};


$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.6.0.v20100505.jar:$plugins_dir/org.eclipse.equinox.common_3.6.0.v20100503.jar:$plugins_dir/org.eclipse.core.filesystem_1.3.1.R36x_v20100727-0745.jar:$plugins_dir/com.ibm.icu.base_4.2.1.v20100412.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/spawner.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$oldClasspath";

if (!defined($timeout))
{
	system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port");
}
else
{
	if (!defined($clientUserID))
	{
		system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port $timeout");
	}
	else
	{
		system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -Dclient.username=$clientUserID -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port $timeout");
	}
}

$ENV{CLASSPATH}=$oldClasspath;
$ENV{LD_LIBRARY_PATH}="$dir:$LD_LIBRARY_PATH";

==> rdt-server-linux.ppc64-6.0.4.tar: rdt-server/server.pl <==
#!/usr/bin/perl
#*******************************************************************************
# Copyright (c) 2005, 2008 IBM Corporation, Wind River Systems, Inc. and others.
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# Contributors:
# IBM Corporation - initial API and implementation
# Martin Oberhuber (Wind River) - Fix bug 149129 - Perl String compare with eq
#*******************************************************************************

$port = $ARGV[0];
$timeout = $ARGV[1];
$clientUserID = $ARGV[2];

$dir= $ENV{PWD};
#print("path $dir");

#$plugins_dir=substr($dir,0,rindex($dir,"/"));
$plugins_dir=$dir;

$ENV{A_PLUGIN_PATH}="$plugins_dir/";

$oldClasspath = $ENV{CLASSPATH};


$ENV{"CLASSPATH"}="$plugins_dir:$plugins_dir/dstore_extra_server.jar:$plugins_dir/dstore_core.jar:$plugins_dir/dstore_miners.jar:$plugins_dir/clientserver.jar:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.8.0.v20120521-2346.jar:$plugins_dir/org.eclipse.equinox.common_3.6.100.v20120522-1841.jar:$plugins_dir/org.eclipse.core.filesystem_1.3.200.v20120522-2012.jar:$plugins_dir/com.ibm.icu.base_4.4.2.v20110831.jar:$plugins_dir/org.eclipse.text_3.5.200.v20120523-1310.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/spawner.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v201004271650.jar:$oldClasspath";

if (!defined($timeout))
{
	system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port");
}
else
{
	if (!defined($clientUserID))
	{
		system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port $timeout");
	}
	else
	{
		system("java -Xms64m -Xmx128m -Xss2m -DA_PLUGIN_PATH=\$A_PLUGIN_PATH -Dclient.username=$clientUserID -DDSTORE_SPIRIT_ON=true org.eclipse.dstore.core.server.Server $port $timeout");
	}
}

$ENV{CLASSPATH}=$oldClasspath;
$ENV{LD_LIBRARY_PATH}="$dir:$LD_LIBRARY_PATH";
